@@ -1,11 +1,8 @@
-from PyObjCTools.TestSupport import *
 import objc
-from Foundation import NSObject
+from Foundation import NSObject, NSRect
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
-try:
-    from Quartz import *
-except ImportError:
-    pass
+import Quartz
 
 
 class TestQLPreviewPanelHelper(NSObject):
@@ -18,20 +15,22 @@ class TestQLPreviewPanelHelper(NSObject):
     def previewPanel_sourceFrameOnScreenForPreviewItem_(self, panel, item):
         return 1
 
-    def previewPanel_transitionImageForPreviewItem_contentRect_(self, panel, item, rect):
+    def previewPanel_transitionImageForPreviewItem_contentRect_(
+        self, panel, item, rect
+    ):
         return 1
 
 
 class TestQLPreviewPanel(TestCase):
     @min_os_level("10.6")
     def testClasses(self):
-        self.assertIsInstance(QLPreviewPanel, objc.objc_class)
+        self.assertIsInstance(Quartz.QLPreviewPanel, objc.objc_class)
 
     @min_os_level("10.6")
     def testMethods(self):
-        self.assertResultIsBOOL(QLPreviewPanel.sharedPreviewPanelExists)
-        self.assertResultIsBOOL(QLPreviewPanel.enterFullScreenMode_withOptions_)
-        self.assertResultIsBOOL(QLPreviewPanel.isInFullScreenMode)
+        self.assertResultIsBOOL(Quartz.QLPreviewPanel.sharedPreviewPanelExists)
+        self.assertResultIsBOOL(Quartz.QLPreviewPanel.enterFullScreenMode_withOptions_)
+        self.assertResultIsBOOL(Quartz.QLPreviewPanel.isInFullScreenMode)
 
         self.assertResultIsBOOL(TestQLPreviewPanelHelper.acceptsPreviewPanelControl_)
         self.assertResultIsBOOL(TestQLPreviewPanelHelper.previewPanel_handleEvent_)
@@ -43,7 +42,7 @@ class TestQLPreviewPanel(TestCase):
         self.assertArgHasType(
             TestQLPreviewPanelHelper.previewPanel_transitionImageForPreviewItem_contentRect_,
             2,
-            objc._C_PTR + NSRect.__typestr__,
+            objc._C_IN + objc._C_PTR + NSRect.__typestr__,
         )
 
     @min_os_level("10.6")
@@ -53,7 +52,3 @@ class TestQLPreviewPanel(TestCase):
     @min_os_level("10.7")
     def testProtocols10_7(self):
         objc.protocolNamed("QLPreviewPanelDelegate")
-
-
-if __name__ == "__main__":
-    main()
